package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaScore;

public interface IBisTtsaScoreService {
    BisTtsaScore selectBisTtsaScoreByGuid(String guid);
    List<BisTtsaScore> selectBisTtsaScoreList(BisTtsaScore bisTtsaScore);
    int insertBisTtsaScore(BisTtsaScore bisTtsaScore);
    int updateBisTtsaScore(BisTtsaScore bisTtsaScore);
    int deleteBisTtsaScoreByGuid(String guid);
    int deleteBisTtsaScoreByGuids(String[] guids);
}
